==> haskell-simple-sendfile-0.2.32-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-AEGdvK3ECn54uJiv4bvrTb
key:                  simple-sendfile-0.2.32-AEGdvK3ECn54uJiv4bvrTb
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  a9ec6f3e84e33e22f019393b56126246
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-AEGdvK3ECn54uJiv4bvrTb
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-3dx8iLR4JM2HWvxqoL7m7K unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.32-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-1amUi5T5a5aKBL9SSRX3fj
key:                  simple-sendfile-0.2.32-1amUi5T5a5aKBL9SSRX3fj
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  39a4c2be5ffd9b58d4503b6eba0f8e2b
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-1amUi5T5a5aKBL9SSRX3fj
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-LColH4Hos0S6e9tGqh8fY1 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
